<?php

/**
 * @file
 * Settings file for Gamertags module.
 */

/**
 * Administrative setting callback.
 */
function gamertags_settings() {
  $form['collect'] = array(
    '#type' => 'fieldset',
    '#title' => t('Usage'),
    '#description' => t('Collect and Display:'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#theme' => 'gamertags_collect',
  );

  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['settings']['gamertags_on_registration'] = array(
    '#type' => 'checkbox',
    '#title' => t('Ask for Gamertags on registration screen'),
    '#description' => t("Check this if you want users to be able to input their Gamertags on the user registration page as well as from their user account pages after they've registered."),
    '#default_value' => variable_get('gamertags_on_registration', TRUE),
  );
  $form['settings']['gamertags_validate_tags'] = array(
    '#type' => 'checkbox',
    '#title' => t('Validate Gamertags'),
    '#description' => t("Check if you want to validate user profile Gamertags.
      <dl>
        <dt>Currently validates:</dt>
        <dd>Playstation (although cannot recognise when a profile isn't activated)</dd>
      </dl>"
    ),
    '#default_value' => variable_get('gamertags_validate_tags', TRUE),
  );
  
  $form['urls'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gamertag URLs'),
    '#description' => t("You should never need to change these settings but if you do,
      note that the URL needs to be fully formed and it <strong>must</strong> contain
      <strong>ONE</strong> string replacement symbol '<strong>%s</strong>' which will
      be where the console username is swapped in.  See the defaults for examples of usage."
    ),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $includes = gamertags_load_includes();
  foreach ($includes as $platform => $include) {
    $function = "gamertags_{$platform}_settings";
    $function($form);
  }

  $form = system_settings_form($form);
  $form['#validate'][] = 'gamertags_settings_validate';
  $form['#theme'] = 'gamertags_settings';

  return $form;
}

/**
 * Form validation for checking URLs contain at least one string replacement symbol.
 */
function gamertags_settings_validate($form, &$form_state) {
  foreach (element_children($form['urls']) as $key) {
    if (!preg_match("/%s/", $form_state['values'][$key])) {
      form_set_error($key, t("Error, URL must contain a string replacement symbol i.e. '%s'"));
    }
    elseif (preg_match_all("/(%s+)/", $form_state['values'][$key], $matches) && count($matches[0]) != 1) {
      form_set_error($key, t("Error, URL must contain only ONE string replacement symbol i.e. '%s'"));
    }
  }
}

/**
 * Themes output for the admin settings form.
 */
function theme_gamertags_settings($form) {
  drupal_add_js(drupal_get_path('module', 'gamertags') .'/misc/settings.js');

  $output = drupal_render($form['collect']);
  $output .= drupal_render($form['settings']);

  // Append messagebox to the fieldset description.
  $form['urls']['#description'] .= '<div id="gamertags_message"'. (_gamertags_test_any() ? '' : ' class="error"') .'>'. (_gamertags_test_any() ? '' : t('No Gamertags are currently set to be displayed.')) .'</div>';

  // If there's something in the messagebox, then don't collapse the fieldset (i.e. display the message).
  if (!_gamertags_test_any()) {
    $form['urls']['#collapsed'] = FALSE;
  }

  $output .= drupal_render($form['urls']);

  // Render any remaining form elements.
  $output .= drupal_render($form);

  return $output;
}

/**
 * Themes output for the collect and display settings.
 */
function theme_gamertags_collect($form) {
  drupal_add_css(drupal_get_path('module', 'gamertags') .'/misc/gamertags.css');

  uasort($form['checkbox'], 'element_sort');

  $rows = array();

  foreach (element_children($form['checkbox']) as $key) {
    $rows[] = array(
        drupal_render($form['checkbox'][$key]),
        drupal_render($form['weight'][preg_replace("/collect/", 'weight', $key)]),
    );
  }

  return '<div id="gamertags-collect-wrapper">'. theme('table', array(t('Gamertag'), t('Weight')), $rows, array('id' => "gamertags-collect")) .'</div>';
}