<?php

/**
 * @file
 * 3DS Friend Code include file.
 */

/**
 * Implementation of gamertags_hook_filter().
 */
function gamertags_ds_filter($op) {
  switch ($op) {
    case 'description':
      return '[3ds:id]';
    case 'long':
      return t('3DS Friend Code by typing [3ds:id]');
    case 'filter':
      return 'ds';
    case 'region':
      return FALSE;
  }
}

/**
 * Implementation of gamertags_hook_theme().
 */
function gamertags_ds_theme() {
  return array(
    'arguments' => array('userid' => NULL),
    'template' => 'templates/gamertags_ds',
  );
}

/**
 * Implementation of gamertags_hook_user().
 */
function gamertags_ds_user(&$user) {
  if (isset($user->ds_gamertag) && $user->ds_gamertag && variable_get('gamertags_collect_ds', TRUE)) {
    $user->content['summary']['ds_gamertag_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('3DS Friend Code'),
      '#value' => theme('gamertags_ds', $user->ds_gamertag),
      '#weight' => variable_get('gamertags_weight_ds', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form().
 */
function gamertags_ds_user_form(&$form, $user) {
  if (variable_get('gamertags_collect_ds', TRUE)) {
    $form['gamertags']['ds_gamertag'] = array(
      '#type' => 'textfield',
      '#title' => t('Nintendo 3DS'),
      '#default_value' => isset($user->ds_gamertag) ? $user->ds_gamertag : '',
      '#description' => t('If you have one, please enter your 3DS Friend Code.'),
      '#weight' => variable_get('gamertags_weight_ds', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form_validate().
 */
function gamertags_ds_user_form_validate(&$edit) {
  // ds validation:
  if (($ds_gamertag = preg_replace(array("/\s+/", "/-+/"), "", $edit['ds_gamertag'])) && (!preg_match("/^[0-9]+$/", $ds_gamertag) || drupal_strlen($ds_gamertag) != 16)) {
    form_set_error('ds_gamertag', t('3DS Friend Codes can be 16 digit numbers only.'));
  }
  // For fun, let's format all ds friendcodes so they look like this 1234-1234-1234-1234.
  if (!empty($ds_gamertag)) {
    $edit['ds_gamertag'] = preg_replace("/([0-9]{4})([0-9]{4})([0-9]{4})([0-9]{4})/", "$1-$2-$3-$4", $ds_gamertag);
  }
}

/**
 * Implementation of gamertags_hook_settings().
 */
function gamertags_ds_settings(&$form) {
  $form['collect']['checkbox']['gamertags_collect_ds'] = array(
    '#type' => 'checkbox',
    '#title' => t('3DS Friend Codes'),
    '#default_value' => variable_get('gamertags_collect_ds', TRUE),
    '#weight' => variable_get('gamertags_weight_ds', 0),
  );
  $form['collect']['weight']['gamertags_weight_ds'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_ds', 0),
  );
  $form['urls']['gamertags_ds_url'] = array(
    '#type' => 'textfield',
    '#title' => t('3DS URL'),
    '#default_value' => variable_get('gamertags_ds_url', "http://mapds.com/ds-number/member.cfm?ds_number=%s"),
    '#required' => TRUE,
    '#size' => 70,
  );
}

/**
 * Implementation of gamertags_hook_return_url().
 */
function gamertags_ds_return_url($userid, $region = NULL) {
  return sprintf(variable_get('gamertags_ds_url', "http://mapds.com/ds-number/member.cfm?ds_number=%s"), preg_replace("/-+/", "", $userid));
}

/**
 * Implementation of gamertags_hook_token_list().
 */
function gamertags_ds_token_list(&$tokens) {
  if (variable_get('gamertags_collect_ds', TRUE)) {
    $tokens['user']['user-gamertag-ds'] = t('Corresponding 3DS Friend Code for this user.');
    $tokens['user']['user-gamertag-ds-text'] = t('Corresponding 3DS Friend Code for this user (as plain text).');
  }
}

/**
 * Implementation of gamertags_hook_token_values().
 */
function gamertags_ds_token_values(&$tokens, $user) {
  if (variable_get('gamertags_collect_ds', TRUE)) {
    $tokens['user-gamertag-ds'] = theme('gamertags_ds', $user->ds_gamertag);
    $tokens['user-gamertag-ds-text'] = check_plain($user->ds_gamertag);
  }
}