<?php

/**
 * @file
 * Playstation Network include file.
 */

/**
 * Implementation of gamertags_hook_filter().
 */
function gamertags_psn_filter($op) {
  switch ($op) {
    case 'description':
      return '[playstation:id:region]';
    case 'long':
      return t('Playstation Network Gamertag by typing [playstation:id:region]');
    case 'filter':
      return 'playstation';
    case 'region':
      return TRUE;
  }
}

/**
 * Implementation of gamertags_hook_theme().
 */
function gamertags_psn_theme() {
  return array(
    'arguments' => array('userid' => NULL, 'region' => NULL),
    'template' => 'templates/gamertags_psn',
  );
}

/**
 * Implementation of gamertags_hook_user().
 */
function gamertags_psn_user(&$user) {
  if (isset($user->psn_gamertag) && $user->psn_gamertag && variable_get('gamertags_collect_psn', TRUE)) {
    $user->content['summary']['psn_gamertag_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Playstation Network Gamertag'),
      '#value' => theme('gamertags_psn', $user->psn_gamertag, $user->psn_region),
      '#weight' => variable_get('gamertags_weight_psn', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form().
 */
function gamertags_psn_user_form(&$form, $user) {
  if (variable_get('gamertags_collect_psn', TRUE)) {
    $form['gamertags']['psn']['#weight'] = variable_get('gamertags_weight_psn', 0);
    $form['gamertags']['psn']['psn_gamertag'] = array(
      '#type' => 'textfield',
      '#title' => t('Playstation Network'),
      '#default_value' => isset($user->psn_gamertag) ? $user->psn_gamertag : '',
      '#description' => t('If you have one, please enter your Playstation Network GamerTag.'),
    );
    $form['gamertags']['psn']['psn_region'] = array(
      '#type' => 'select',
      '#title' => t('Playstation Region'),
      '#options' => array('na' => t('N/A'), 'eu' => t('Europe'), 'us' => t('America')),
      '#default_value' => isset($user->psn_region) ? $user->psn_region : '',
      '#required' => TRUE, // Set to TRUE although it's pointless as there's no NULL value - this is just for emphasis.
      '#description' => t("As Sony don't seem to have thought this through properly, please enter the region for your PSN gamertag."),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form_validate().
 */
function gamertags_psn_user_form_validate(&$edit) {
  // Playstation validation:
  if (($psn_gamertag = $edit['psn_gamertag']) && (!preg_match("/^[a-zA-Z]{1}[a-zA-Z0-9-_]+$/", $psn_gamertag) || drupal_strlen($psn_gamertag) < 3 || drupal_strlen($psn_gamertag) > 16)) {
    form_set_error('psn_gamertag', t('Playstation Network gamertag field should begin with a letter, only contain numbers, letters, hyphens and underscores and be between 3 to 16 characters in length.'));
  }
  // Not all users will have js enabled so pick up the possibility that N/A may have been chosen when the field is required.
  if (!empty($psn_gamertag) && $edit['psn_region'] == 'na') {
    form_set_error('psn_region', t('The Playstation Network region field is required when you enter a PSN gamertag.'));
  }
  // Validation:
  if (variable_get('gamertags_validate_tags', TRUE)) {
    if (!empty($psn_gamertag) && ($url = gamertags_return_url('playstation', $psn_gamertag, $edit['psn_region'])) && drupal_http_request($url)->code != 200) {
      drupal_set_message(t("Warning, either your Playstation gamertag doesn't exist (please check your spelling) or you haven't yet activated your profile."), 'error');
    }
  }
}

/**
 * Implementation of gamertags_hook_settings().
 */
function gamertags_psn_settings(&$form) {
  $form['collect']['checkbox']['gamertags_collect_psn'] = array(
    '#type' => 'checkbox',
    '#title' => t("Playstation Gamertags"),
    '#default_value' => variable_get('gamertags_collect_psn', TRUE),
    '#weight' => variable_get('gamertags_weight_psn', 0),
  );
  $form['collect']['weight']['gamertags_weight_psn'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_psn', 0),
  );
  $form['urls']['gamertags_psn_eu_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (European) URL'),
    '#default_value' => variable_get('gamertags_psn_eu_url', "http://mypsn.eu.playstation.com/psn/profile/%s.jpg"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_psn_us_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (American) URL'),
    '#default_value' => variable_get('gamertags_psn_us_url', "http://fp.profiles.us.playstation.com/playstation/psn/pid/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
}

/**
 * Implementation of gamertags_hook_return_url().
 */
function gamertags_psn_return_url($userid, $region = NULL) {
  switch ($region) {
    default:
      return sprintf(variable_get('gamertags_psn_eu_url', "http://mypsn.eu.playstation.com/psn/profile/%s.jpg"), $userid);
    case 'us':
      return sprintf(variable_get('gamertags_psn_us_url', "http://fp.profiles.us.playstation.com/playstation/psn/pid/%s.png"), $userid);
  }
}

/**
 * Implementation of gamertags_hook_token_list().
 */
function gamertags_psn_token_list(&$tokens) {
  if (variable_get('gamertags_collect_psn', TRUE)) {
    $tokens['user']['user-gamertag-psn'] = t('Corresponding Playstation Network Gamertag for this user.');
    $tokens['user']['user-gamertag-psn-text'] = t('Corresponding Playstation Network Gamertag for this user (as plain text).');
  }
}

/**
 * Implementation of gamertags_hook_token_values().
 */
function gamertags_psn_token_values(&$tokens, $user) {
  if (variable_get('gamertags_collect_psn', TRUE)) {
    $tokens['user-gamertag-psn'] = theme('gamertags_playstation', $user->psn_gamertag, $user->psn_region);
    $tokens['user-gamertag-psn-text'] = check_plain($user->psn_gamertag);
  }
}