<?php

/**
 * @file
 * Steam Network include file.
 */

/**
 * Implementation of gamertags_hook_filter().
 */
function gamertags_steam_filter($op) {
  switch ($op) {
    case 'description':
      return '[steam:id]';
    case 'long':
      return t('Steam Gamercard by typing [steam:id]');
    case 'filter':
      return 'steam';
    case 'region':
      return FALSE;
  }
}

/**
 * Implementation of gamertags_hook_theme().
 */
function gamertags_steam_theme() {
  return array(
    'arguments' => array('userid' => NULL),
    'template' => 'templates/gamertags_steam',
  );
}

/**
 * Implementation of gamertags_hook_user().
 */
function gamertags_steam_user(&$user) {
  if (isset($user->steam_gamertag) && $user->steam_gamertag && variable_get('gamertags_collect_steam', TRUE)) {
    $user->content['summary']['steam_gamertag_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Steam Network Gamertag'),
      '#value' => theme('gamertags_steam', $user->steam_gamertag),
      '#weight' => variable_get('gamertags_weight_steam', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form().
 */
function gamertags_steam_user_form(&$form, $user) {
  if (variable_get('gamertags_collect_steam', TRUE)) {
    $form['gamertags']['steam_gamertag'] = array(
      '#type' => 'textfield',
      '#title' => t('Steam'),
      '#default_value' => isset($user->steam_gamertag) ? $user->steam_gamertag : '',
      '#description' => t('If you have one, please enter your Steam GamerTag.'),
      '#weight' => variable_get('gamertags_weight_steam', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form_validate().
 */
function gamertags_steam_user_form_validate(&$edit) {
  // Steam validation:
  if (($steam_gamertag = $edit['steam_gamertag']) && (!preg_match("/^[a-zA-Z0-9_]+$/", $steam_gamertag))) {
    form_set_error('steam_gamertag', t("Steam gamertag field should contain numbers, letters and underscores only."));
  }
}

/**
 * Implementation of gamertags_hook_settings().
 */
function gamertags_steam_settings(&$form) {
  $form['collect']['checkbox']['gamertags_collect_steam'] = array(
    '#type' => 'checkbox',
    '#title' => t("Steam Gamertags"),
    '#default_value' => variable_get('gamertags_collect_steam', TRUE),
    '#weight' => variable_get('gamertags_weight_steam', 0),
  );
  $form['collect']['weight']['gamertags_weight_steam'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_steam', 0),
  );
  $form['urls']['gamertags_steam_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Steam Card URL'),
    '#default_value' => variable_get('gamertags_steam_url', "http://steamcard.com/do/modern/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
}

/**
 * Implementation of gamertags_hook_return_url().
 */
function gamertags_steam_return_url($userid, $region = NULL) {
  return sprintf(variable_get('gamertags_steam_url', "http://steamcard.com/do/modern/%s.png"), $userid);
}

/**
 * Implementation of gamertags_hook_token_list().
 */
function gamertags_steam_token_list(&$tokens) {
  if (variable_get('gamertags_collect_steam', TRUE)) {
    $tokens['user']['user-gamertag-steam'] = t('Corresponding Steam card for this user.');
    $tokens['user']['user-gamertag-steam-text'] = t('Corresponding Steam card for this user (as plain text).');
  }
}

/**
 * Implementation of gamertags_hook_token_values().
 */
function gamertags_steam_token_values(&$tokens, $user) {
  if (variable_get('gamertags_collect_steam', TRUE)) {
    $tokens['user-gamertag-steam'] = theme('gamertags_steam', $user->steam_gamertag);
    $tokens['user-gamertag-steam-text'] = check_plain($user->steam_gamertag);
  }
}