<?php

/**
 * @file
 * Wii Friend Code include file.
 */

/**
 * Implementation of gamertags_hook_filter().
 */
function gamertags_wii_filter($op) {
  switch ($op) {
    case 'description':
      return '[wii:id]';
    case 'long':
      return t('Wii Friend Code by typing [wii:id]');
    case 'filter':
      return 'wii';
    case 'region':
      return FALSE;
  }
}

/**
 * Implementation of gamertags_hook_theme().
 */
function gamertags_wii_theme() {
  return array(
    'arguments' => array('userid' => NULL),
    'template' => 'templates/gamertags_wii',
  );
}

/**
 * Implementation of gamertags_hook_user().
 */
function gamertags_wii_user(&$user) {
  if (isset($user->wii_gamertag) && $user->wii_gamertag && variable_get('gamertags_collect_wii', TRUE)) {
    $user->content['summary']['wii_gamertag_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Wii Friend Code'),
      '#value' => theme('gamertags_wii', $user->wii_gamertag),
      '#weight' => variable_get('gamertags_weight_wii', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form().
 */
function gamertags_wii_user_form(&$form, $user) {
  if (variable_get('gamertags_collect_wii', TRUE)) {
    $form['gamertags']['wii_gamertag'] = array(
      '#type' => 'textfield',
      '#title' => t('Nintendo Wii'),
      '#default_value' => isset($user->wii_gamertag) ? $user->wii_gamertag : '',
      '#description' => t('If you have one, please enter your Wii Friend Code.'),
      '#weight' => variable_get('gamertags_weight_wii', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form_validate().
 */
function gamertags_wii_user_form_validate(&$edit) {
  // Wii validation:
  if (($wii_gamertag = preg_replace(array("/\s+/", "/-+/"), "", $edit['wii_gamertag'])) && (!preg_match("/^[0-9]+$/", $wii_gamertag) || drupal_strlen($wii_gamertag) != 16)) {
    form_set_error('wii_gamertag', t('Wii Friend Codes can be 16 digit numbers only.'));
  }
  // For fun, let's format all Wii friendcodes so they look like this 1234-1234-1234-1234.
  if (!empty($wii_gamertag)) {
    $edit['wii_gamertag'] = preg_replace("/([0-9]{4})([0-9]{4})([0-9]{4})([0-9]{4})/", "$1-$2-$3-$4", $wii_gamertag);
  }
}

/**
 * Implementation of gamertags_hook_settings().
 */
function gamertags_wii_settings(&$form) {
  $form['collect']['checkbox']['gamertags_collect_wii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Wii Friend Codes"),
    '#default_value' => variable_get('gamertags_collect_wii', TRUE),
    '#weight' => variable_get('gamertags_weight_wii', 0),
  );
  $form['collect']['weight']['gamertags_weight_wii'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_wii', 0),
  );
  $form['settings']['gamertags_use_mapwii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Use mapwii.com for Wii Friend Codes"),
    '#description' => t("Check this box to allow users wii friend codes to link through to the mapwii.com friend code repository."),
    '#default_value' => variable_get('gamertags_use_mapwii', FALSE),
  );
  $form['urls']['gamertags_wii_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Wii URL'),
    '#default_value' => variable_get('gamertags_wii_url', "http://mapwii.com/wii-number/member.cfm?wii_number=%s"),
    '#required' => TRUE,
    '#size' => 70,
  );
}

/**
 * Implementation of gamertags_hook_return_url().
 */
function gamertags_wii_return_url($userid, $region = NULL) {
  return sprintf(variable_get('gamertags_wii_url', "http://mapwii.com/wii-number/member.cfm?wii_number=%s"), preg_replace("/-+/", "", $userid));
}

/**
 * Implementation of gamertags_hook_token_list().
 */
function gamertags_wii_token_list(&$tokens) {
  if (variable_get('gamertags_collect_wii', TRUE)) {
    $tokens['user']['user-gamertag-wii'] = t('Corresponding Wii Friend Code for this user.');
    $tokens['user']['user-gamertag-wii-text'] = t('Corresponding Wii Friend Code for this user (as plain text).');
  }
}

/**
 * Implementation of gamertags_hook_token_values().
 */
function gamertags_wii_token_values(&$tokens, $user) {
  if (variable_get('gamertags_collect_wii', TRUE)) {
    $tokens['user-gamertag-wii'] = theme('gamertags_wii', $user->wii_gamertag);
    $tokens['user-gamertag-wii-text'] = check_plain($user->wii_gamertag);
  }
}