<?php

/**
 * @file
 * Xbox Live include file.
 */

/**
 * Implementation of gamertags_hook_filter().
 */
function gamertags_xbox_filter($op) {
  switch ($op) {
    case 'description':
      return '[xbox:id]';
    case 'long':
      return t('Xbox Live Gamertag by typing [xbox:id]');
    case 'filter':
      return 'xbox';
    case 'region':
      return FALSE;
  }
}

/**
 * Implementation of gamertags_hook_theme().
 */
function gamertags_xbox_theme() {
  return array(
    'arguments' => array('userid' => NULL),
    'template' => 'templates/gamertags_xbox',
  );
}

/**
 * Implementation of gamertags_hook_user().
 */
function gamertags_xbox_user(&$user) {
  if (isset($user->xbox_gamertag) && $user->xbox_gamertag && variable_get('gamertags_collect_xbox', TRUE)) {
    $user->content['summary']['xbox_gamertag_view'] = array(
      '#type' => 'user_profile_item',
      '#title' => t('Xbox Live Gamertag'),
      '#value' => theme('gamertags_xbox', $user->xbox_gamertag),
      '#weight' => variable_get('gamertags_weight_xbox', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form().
 */
function gamertags_xbox_user_form(&$form, $user) {
  if (variable_get('gamertags_collect_xbox', TRUE)) {
    $form['gamertags']['xbox_gamertag'] = array(
      '#type' => 'textfield',
      '#title' => t('Xbox Live'),
      '#default_value' => isset($user->xbox_gamertag) ? $user->xbox_gamertag : '',
      '#description' => t('If you have one, please enter your Xbox Live GamerTag.'),
      '#weight' => variable_get('gamertags_weight_xbox', 0),
    );
  }
}

/**
 * Implementation of gamertags_hook_user_form_validate().
 */
function gamertags_xbox_user_form_validate(&$edit) {
  if ($edit['xbox_gamertag'] && (!preg_match("/^[a-zA-Z]{1}[a-zA-Z0-9 ]+$/", $edit['xbox_gamertag']) || drupal_strlen($edit['xbox_gamertag']) > 15)) {
    form_set_error('xbox_gamertag', t('Xbox Live gamertag field should contain numbers, letters and spaces only and be up to 15 characters in length.'));
  }
}

/**
 * Implementation of gamertags_hook_settings().
 */
function gamertags_xbox_settings(&$form) {
  $form['collect']['checkbox']['gamertags_collect_xbox'] = array(
    '#type' => 'checkbox',
    '#title' => t('Xbox Gamertags'),
    '#default_value' => variable_get('gamertags_collect_xbox', TRUE),
    '#weight' => variable_get('gamertags_weight_xbox', 0),
  );
  $form['collect']['weight']['gamertags_weight_xbox'] = array(
    '#type' => 'weight',
    '#delta' => 50,
    '#default_value' => variable_get('gamertags_weight_xbox', 0),
  );
  $form['urls']['gamertags_xbox_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Xbox URL'),
    '#default_value' => variable_get('gamertags_xbox_url', "http://gamercard.xbox.com/%s.card"),
    '#required' => TRUE,
    '#size' => 70,
  );
}

/**
 * Implementation of gamertags_hook_return_url().
 */
function gamertags_xbox_return_url($userid, $region = NULL) {
  return sprintf(variable_get('gamertags_xbox_url', "http://gamercard.xbox.com/%s.card"), $userid);
}

/**
 * Implementation of gamertags_hook_token_list().
 */
function gamertags_xbox_token_list(&$tokens) {
  if (variable_get('gamertags_collect_xbox', TRUE)) {
    $tokens['user']['user-gamertag-xbox'] = t('Corresponding Xbox Gamertag for this user.');
    $tokens['user']['user-gamertag-xbox-text'] = t('Corresponding Xbox Gamertag for this user (as plain text).');
  }
}

/**
 * Implementation of gamertags_hook_token_values().
 */
function gamertags_xbox_token_values(&$tokens, $user) {
  if (variable_get('gamertags_collect_xbox', TRUE)) {
    $tokens['user-gamertag-xbox'] = theme('gamertags_xbox', $user->xbox_gamertag);
    $tokens['user-gamertag-xbox-text'] = check_plain($user->xbox_gamertag);
  }
}